def add_numbers(num1, num2):
    return num1 + num2

def sus_numbers(num1, num2):
    return num1 - num2

def mul_numbers(num1, num2):
    return num1 * num2

def devide_numbers(num1, num2):
    return num1 / num2


